<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       ifelsetech.com
 * @since      1.0.0
 *
 * @package    Jewellery_Price
 * @subpackage Jewellery_Price/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Jewellery_Price
 * @subpackage Jewellery_Price/includes
 * @author     ifelsetech <dev@ifelsetech.com>
 */
class Jewellery_Price
{

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Jewellery_Price_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct()
	{
		if (defined('JEWELLERY_PRICE_VERSION')) {
			$this->version = JEWELLERY_PRICE_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'jewellery-price';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Jewellery_Price_Loader. Orchestrates the hooks of the plugin.
	 * - Jewellery_Price_i18n. Defines internationalization functionality.
	 * - Jewellery_Price_Admin. Defines all hooks for the admin area.
	 * - Jewellery_Price_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies()
	{

	
		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 * 
		 */
		 
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-jewellery-price-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-jewellery-price-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-jewellery-price-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-jewellery-price-public.php';

		$this->loader = new Jewellery_Price_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Jewellery_Price_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale()
	{

		$plugin_i18n = new Jewellery_Price_i18n();

		$this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks()
	{

		$plugin_admin = new Jewellery_Price_Admin($this->get_plugin_name(), $this->get_version(),$this->activate_product());

		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
		$this->loader->add_action('admin_menu', $plugin_admin, 'its_jp_admin_menu');
		$this->loader->add_action("wp_ajax_admin_ajax_request", $plugin_admin, 'handle_ajax_request_admin');
		$this->loader->add_action("woocommerce_product_options_pricing", $plugin_admin, 'its_jp_product_options_pricing');
		$this->loader->add_action('woocommerce_process_product_meta_simple', $plugin_admin, 'its_jp_process_product_meta');
		$this->loader->add_action('woocommerce_product_after_variable_attributes', $plugin_admin, 'variation_settings_fields', 10, 3);
		$this->loader->add_action('woocommerce_save_product_variation', $plugin_admin, 'save_variation_settings_fields', 10, 2);
		$this->loader->add_filter('woocommerce_available_variation', $plugin_admin, 'load_variation_settings_fields');
		//add_filter( 'admin_footer_text', '__return_empty_string', 11 ); 
		//add_filter( 'update_footer', '__return_empty_string', 11 );

        


		
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks()
	{

		$plugin_public = new Jewellery_Price_Public($this->get_plugin_name(), $this->get_version(),$this->activate_product());

		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
	
		$this->loader->add_action('wp_ajax_its_jp_public_ajax_request',$plugin_public, 'its_jp_public_ajax_function' );
		$this->loader->add_action('wp_ajax_nopriv_its_jp_public_ajax_request',$plugin_public, 'its_jp_public_ajax_function' );
        // Price breakup functionality
		$itsjp_pricebreakup_settings = get_option('itsjp-pricebreakup-settings',false); 
		if(isset($itsjp_pricebreakup_settings['enablePriceBreakup']) && $itsjp_pricebreakup_settings['enablePriceBreakup'] == 1 ){
			if(isset($itsjp_pricebreakup_settings['price_breakup_location_below_addtocart']) && $itsjp_pricebreakup_settings['price_breakup_location_below_addtocart'] == "below_addtocart" ){
				$this->loader->add_action('woocommerce_single_product_summary',$plugin_public,'its_variable_product_price_breakup',40);
				$this->loader->add_action('woocommerce_single_product_summary',$plugin_public,'its_simple_product_price_breakup',40);
			}
		$this->loader->add_action('wp_ajax_its_variable_product_price_breakup_ajax_request',$plugin_public, 'its_variable_product_price_breakup_ajax_function' );
		$this->loader->add_action('wp_ajax_nopriv_its_variable_product_price_breakup_ajax_request',$plugin_public, 'its_variable_product_price_breakup_ajax_function' );
	}
	$this->loader->add_action('init',$plugin_public,'itsjp_add_shortcodes');
    }

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run()
	{
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name()
	{
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Jewellery_Price_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader()
	{
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version()
	{
		return $this->version;
	}
	public function activate_product(){
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/license.php';
		$licensekey = get_option('itsjpp_license_key');
$localkey = get_option('itsjpp_local_key');

// Validate the license key information
$results = itsjp_check_license($licensekey, $localkey);

// Raw output of results for debugging purpose
//echo '<textarea cols="100" rows="20">' . print_r($results, true) . '</textarea>';

// Interpret response
if(isset($results['addons'])){

	$tempresults = explode("|",$results["addons"]);
	foreach ($tempresults AS $tempresult) {
	  $tempresults2 = explode(";",$tempresult);
	  $temparr = array();
	 
	  foreach ($tempresults2 AS $tempresult) {
	  $tempresults3 = explode("=",$tempresult);
		$temparr[$tempresults3[0]] = $tempresults3[1];
	  }
	 
	  $addons[] = $temparr;
	}
	$results['addon-details'] = $addons;
}


if($results['status'] == 'Active')
{
	if($results['productid'] == 43)
	{
	    $datetime = new DateTime($results['regdate']);
	    $datetime->add(new DateInterval('P7D'));
	    $results['nextduedate'] = $datetime->format('Y-m-d');
	}
    $days_active = date("Y-m-d") <= $results['nextduedate'];
}

switch ($results['status']) {
    case "Active":
        // get new local key and save it somewhere
        $itsjp_activated = ($days_active) ? true : false;
				if(isset($results['localkey'])){
					update_option('itsjpp_local_key',$results['localkey']);
				}

        break;
    case "Invalid":
       // die("License key is Invalid");
       $itsjp_activated = false;
        break;
    case "Expired":
       // die("License key is Expired");
       $itsjp_activated = false;
        break;
    case "Suspended":
       // die("License key is Suspended");
       $itsjp_activated = false;
        break;
    default:
      //  die("Invalid Response");
      $itsjp_activated = false;
        break;
}
$results['licensekey'] = ($itsjp_activated) ? $licensekey : '';
$results['activated'] = $itsjp_activated;
//print_r($results);
return $results;
	}
}